@@ -47,7 +47,9 @@ class AndroidConnector(BaseSandboxConnector):
 
     def run_file_analysis(
             self,
-            file: Union[str, bytes],
+            file_content: Optional[bytes] = None,
+            filename: Optional[str] = None,
+            filepath: Optional[str] = None,
             env_locale: str = 'en-US',
             opt_network_connect: bool = True,
             opt_network_fakenet: bool = False,
@@ -60,14 +62,17 @@ class AndroidConnector(BaseSandboxConnector):
             opt_timeout: int = 60,
             opt_automated_interactivity: bool = True,
             obj_ext_cmd: Optional[str] = None,
-            user_tag: Optional[str] = None,
+            user_tags: Optional[str] = None,
             task_rerun_uuid: Optional[str] = None
     ) -> Union[UUID, str]:
         """
         Initializes a new file analysis according to the specified parameters
         You can find extended documentation `here <https://any.run/api-documentation/#api-Analysis-PostAnalysis>`_
+        Options: file_content and filename have higher priority then filepath option
 
-        :param file: File to analyse. Path to file, or bytes object
+        :param file_content: File bytes to analyse.
+        :param filename: Filename with file extension.
+        :param filepath: Absolute path to file. If specified, automatically process file content and filename
         :param env_locale: Operation system's language. Use locale identifier or country name (Ex: "en-US" or "Brazil").
             Case insensitive.
         :param opt_network_connect: Network connection state
@@ -81,7 +86,7 @@ class AndroidConnector(BaseSandboxConnector):
         :param opt_timeout: Timeout option. Size range: 10-660
         :param opt_automated_interactivity: Automated Interactivity (ML) option
         :param obj_ext_cmd: Optional command line.
-        :param user_tag: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
+        :param user_tags: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
             are allowed. Max tag length: 16 characters. Max unique tags per task: 8.
         :param task_rerun_uuid: Completed task identifier. Re-runs an existent task if uuid is specified. You can re-run
             task with new parameters
@@ -89,7 +94,9 @@ class AndroidConnector(BaseSandboxConnector):
         """
         return execute_synchronously(
             self.run_file_analysis_async,
-            file=file,
+            file_content=file_content,
+            filename=filename,
+            filepath=filepath,
             env_locale=env_locale,
             opt_network_connect=opt_network_connect,
             opt_network_fakenet=opt_network_fakenet,
@@ -103,12 +110,14 @@ class AndroidConnector(BaseSandboxConnector):
             opt_automated_interactivity=opt_automated_interactivity,
             obj_ext_cmd=obj_ext_cmd,
             task_rerun_uuid=task_rerun_uuid,
-            user_tag=user_tag
+            user_tags=user_tags
         )
 
     async def run_file_analysis_async(
             self,
-            file: Union[str, bytes],
+            file_content: Optional[bytes] = None,
+            filename: Optional[str] = None,
+            filepath: Optional[str] = None,
             env_locale: str = 'en-US',
             opt_network_connect: bool = True,
             opt_network_fakenet: bool = False,
@@ -121,14 +130,17 @@ class AndroidConnector(BaseSandboxConnector):
             opt_timeout: int = 60,
             opt_automated_interactivity: bool = True,
             obj_ext_cmd: Optional[str] = None,
-            user_tag: Optional[str] = None,
+            user_tags: Optional[str] = None,
             task_rerun_uuid: Optional[str] = None
     ) -> Union[UUID, str]:
         """
         Initializes a new file analysis according to the specified parameters
         You can find extended documentation `here <https://any.run/api-documentation/#api-Analysis-PostAnalysis>`_
+        Options: file_content and filename have higher priority then filepath option
 
-        :param file: File to analyse. Path to file, or bytes object
+        :param file_content: File bytes to analyse.
+        :param filename: Filename with file extension.
+        :param filepath: Absolute path to file. If specified, automatically process file content and filename
         :param env_locale: Operation system's language. Use locale identifier or country name (Ex: "en-US" or "Brazil").
             Case insensitive.
         :param opt_network_connect: Network connection state
@@ -142,38 +154,47 @@ class AndroidConnector(BaseSandboxConnector):
         :param opt_timeout: Timeout option. Size range: 10-660
         :param opt_automated_interactivity: Automated Interactivity (ML) option
         :param obj_ext_cmd: Optional command line.
-        :param user_tag: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
+        :param user_tags: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
             are allowed. Max tag length: 16 characters. Max unique tags per task: 8.
         :param task_rerun_uuid: Completed task identifier. Re-runs an existent task if uuid is specified. You can re-run
             task with new parameters
         :return: Task uuid
         """
         url = f'{Config.ANY_RUN_API_URL}/analysis'
+        params = {
+            'env_os': 'android',
+            'env_version': '14',
+            'env_bitness': '64',
+            'env_type': 'complete',
+            'env_locale': env_locale,
+            'opt_network_connect': opt_network_connect,
+            'opt_network_fakenet': opt_network_fakenet,
+            'opt_network_tor': opt_network_tor,
+            'opt_network_geo': opt_network_geo,
+            'opt_network_mitm': opt_network_mitm,
+            'opt_network_residential_proxy': opt_network_residential_proxy,
+            'opt_network_residential_proxy_geo': opt_network_residential_proxy_geo,
+            'opt_privacy_type': opt_privacy_type,
+            'opt_timeout': opt_timeout,
+            'opt_automated_interactivity': opt_automated_interactivity,
+            'obj_ext_startfolder': 'downloads',
+            'obj_ext_cmd': obj_ext_cmd,
+            'task_rerun_uuid': task_rerun_uuid,
+            'user_tags': user_tags
+        }
 
-        body = await self._generate_multipart_request_body(
-            file,
-            env_os='android',
-            env_version='14',
-            env_bitness='64',
-            env_type='complete',
-            env_locale=env_locale,
-            opt_network_connect=opt_network_connect,
-            opt_network_fakenet=opt_network_fakenet,
-            opt_network_tor=opt_network_tor,
-            opt_network_geo=opt_network_geo,
-            opt_network_mitm=opt_network_mitm,
-            opt_network_residential_proxy=opt_network_residential_proxy,
-            opt_network_residential_proxy_geo=opt_network_residential_proxy_geo,
-            opt_privacy_type=opt_privacy_type,
-            opt_timeout=opt_timeout,
-            opt_automated_interactivity=opt_automated_interactivity,
-            obj_ext_startfolder='downloads',
-            obj_ext_cmd=obj_ext_cmd,
-            task_rerun_uuid=task_rerun_uuid,
-            user_tag=user_tag
-        )
-
-        response_data = await self._make_request_async('POST', url, data=body)
+        if self._enable_requests:
+            file_content, filename = await self._get_file_payload(file_content, filename, filepath)
+            files = {filename: (filename, file_content)}
+            response_data = await self._make_request_async('POST', url, json=params, files=files)
+        else:
+            body = await self._generate_multipart_request_body(
+                file_content=file_content,
+                filename=filename,
+                filepath=filepath,
+                **params
+            )
+            response_data = await self._make_request_async('POST', url, data=body)
         return response_data.get('data').get('taskid')
 
     def run_url_analysis(
@@ -190,8 +211,7 @@ class AndroidConnector(BaseSandboxConnector):
             opt_privacy_type: str = 'bylink',
             opt_timeout: int = 60,
             opt_automated_interactivity: bool = True,
-            obj_ext_browser: str = 'Google Chrome',
-            user_tag: Optional[str] = None,
+            user_tags: Optional[str] = None,
             task_rerun_uuid: Optional[str] = None
     ) -> Union[UUID, str]:
         """
@@ -211,8 +231,7 @@ class AndroidConnector(BaseSandboxConnector):
         :param opt_privacy_type: Privacy settings. Supports: public, bylink, owner, byteam
         :param opt_timeout: Timeout option. Size range: 10-660
         :param opt_automated_interactivity: Automated Interactivity (ML) option
-        :param obj_ext_browser: Browser name. Supports: Google Chrome, Mozilla Firefox
-        :param user_tag: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
+        :param user_tags: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
             are allowed. Max tag length: 16 characters. Max unique tags per task: 8.
         :param task_rerun_uuid: Completed task identifier. Re-runs an existent task if uuid is specified. You can re-run
             task with new parameters
@@ -233,8 +252,7 @@ class AndroidConnector(BaseSandboxConnector):
             opt_timeout=opt_timeout,
             opt_automated_interactivity=opt_automated_interactivity,
             task_rerun_uuid=task_rerun_uuid,
-            obj_ext_browser=obj_ext_browser,
-            user_tag=user_tag
+            user_tags=user_tags
         )
 
     async def run_url_analysis_async(
@@ -251,8 +269,7 @@ class AndroidConnector(BaseSandboxConnector):
             opt_privacy_type: str = 'bylink',
             opt_timeout: int = 60,
             opt_automated_interactivity: bool = True,
-            obj_ext_browser: str = 'Google Chrome',
-            user_tag: Optional[str] = None,
+            user_tags: Optional[str] = None,
             task_rerun_uuid: Optional[str] = None
     ) -> Union[UUID, str]:
         """
@@ -272,8 +289,7 @@ class AndroidConnector(BaseSandboxConnector):
         :param opt_privacy_type: Privacy settings. Supports: public, bylink, owner, byteam
         :param opt_timeout: Timeout option. Size range: 10-660
         :param opt_automated_interactivity: Automated Interactivity (ML) option
-        :param obj_ext_browser: Browser name. Supports: Google Chrome, Mozilla Firefox
-        :param user_tag: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
+        :param user_tags: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
             are allowed. Max tag length: 16 characters. Max unique tags per task: 8.
         :param task_rerun_uuid: Completed task identifier. Re-runs an existent task if uuid is specified. You can re-run
             task with new parameters
@@ -300,8 +316,7 @@ class AndroidConnector(BaseSandboxConnector):
             opt_timeout=opt_timeout,
             opt_automated_interactivity=opt_automated_interactivity,
             task_rerun_uuid=task_rerun_uuid,
-            obj_ext_browser=obj_ext_browser,
-            user_tag=user_tag
+            user_tags=user_tags
         )
         response_data = await self._make_request_async('POST', url, json=body)
         return response_data.get('data').get('taskid')
@@ -323,7 +338,7 @@ class AndroidConnector(BaseSandboxConnector):
             obj_ext_cmd: Optional[str] = None,
             obj_ext_useragent: Optional[str] = None,
             opt_privacy_hidesource: bool = False,
-            user_tag: Optional[str] = None,
+            user_tags: Optional[str] = None,
             task_rerun_uuid: Optional[str] = None
     ) -> Union[UUID, str]:
         """
@@ -345,7 +360,7 @@ class AndroidConnector(BaseSandboxConnector):
         :param opt_automated_interactivity: Automated Interactivity (ML) option
         :param obj_ext_cmd: Optional command line.
         :param obj_ext_useragent: User-Agent value.
-        :param user_tag: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
+        :param user_tags: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
             are allowed. Max tag length: 16 characters. Max unique tags per task: 8.
         :param opt_privacy_hidesource: Option for hiding of source URL.
         :param task_rerun_uuid: Completed task identifier. Re-runs an existent task if uuid is specified. You can re-run
@@ -370,7 +385,7 @@ class AndroidConnector(BaseSandboxConnector):
             obj_ext_cmd=obj_ext_cmd,
             obj_ext_useragent=obj_ext_useragent,
             opt_privacy_hidesource=opt_privacy_hidesource,
-            user_tag=user_tag
+            user_tags=user_tags
         )
 
     async def run_download_analysis_async(
@@ -390,7 +405,7 @@ class AndroidConnector(BaseSandboxConnector):
             obj_ext_cmd: Optional[str] = None,
             obj_ext_useragent: Optional[str] = None,
             opt_privacy_hidesource: bool = False,
-            user_tag: Optional[str] = None,
+            user_tags: Optional[str] = None,
             task_rerun_uuid: Optional[str] = None
     ) -> Union[UUID, str]:
         """
@@ -413,7 +428,7 @@ class AndroidConnector(BaseSandboxConnector):
         :param obj_ext_cmd: Optional command line.
         :param obj_ext_useragent: User-Agent value.
         :param opt_privacy_hidesource: Option for hiding of source URL.
-        :param user_tag: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
+        :param user_tags: Append user tags to new analysis. Only characters a-z, A-Z, 0-9, hyphen (-), and comma (,)
             are allowed. Max tag length: 16 characters. Max unique tags per task: 8.
         :param task_rerun_uuid: Completed task identifier. Re-runs an existent task if uuid is specified. You can re-run
             task with new parameters
@@ -444,7 +459,7 @@ class AndroidConnector(BaseSandboxConnector):
             obj_ext_cmd=obj_ext_cmd,
             obj_ext_useragent=obj_ext_useragent,
             opt_privacy_hidesource=opt_privacy_hidesource,
-            user_tag=user_tag
+            user_tags=user_tags
         )
 
         response_data = await self._make_request_async('POST', url, json=body)
